@@ -14,11 +14,12 @@ build = "797"
 
 sh = ['scribo']
 desktop_file = ['scribo.desktop']
-pixmaps = glob.glob('data/*.png') + glob.glob('data/*.ico')
-srcs = glob.glob('src/*.py') + glob.glob('src/ui/*.py') + \
-        glob.glob('src/bugz/*.py') + glob.glob('src/ldm/*.py') + \
-        glob.glob('src/services/*.py')
-
+pixmaps = glob.glob('data/*.png')+ glob.glob('data/*.ico')
+srcs = glob.glob('src/*.py') 
+uisrcs =  glob.glob('src/ui/*.py') 
+bugsrcs =  glob.glob('src/bugz/*.py') 
+ldmsrcs = glob.glob('src/ldm/*.py') 
+servsrcs = glob.glob('src/services/*.py')
 inst_dbus = ['scribo.service']
 inst_icon = ['data/Scribo.png']
 inst_icon_sca = ['data/Scribo.png']
@@ -39,6 +40,10 @@ docs_files = ["README", "copying", "NEWS", "TODO", "INSTALL",]
 data_files = [
   ('/usr/share/applications/hildon', desktop_file),
   ('/opt/scribo/src', srcs),
+  ('/opt/scribo/src/ui', uisrcs),
+  ('/opt/scribo/src/bug', bugsrcs),
+  ('/opt/scribo/src/ldm', ldmsrcs),
+  ('/opt/scribo/src/services', servsrcs),
   ('/opt/scribo/data', pixmaps),
   ('/usr/share/dbus-1/services', inst_dbus),
   ('/usr/share/icons/hicolor/26x26/hildon/', inst_icon),
